package cn.ibizlab.businesscentral.core.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.businesscentral.core.dto.*;
import cn.ibizlab.businesscentral.core.mapping.*;
import cn.ibizlab.businesscentral.core.odoo_account.domain.Account_analytic_line;
import cn.ibizlab.businesscentral.core.odoo_account.service.IAccount_analytic_lineService;
import cn.ibizlab.businesscentral.core.odoo_account.filter.Account_analytic_lineSearchContext;
import cn.ibizlab.businesscentral.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"分析行" })
@RestController("Core-account_analytic_line")
@RequestMapping("")
public class Account_analytic_lineResource {

    @Autowired
    public IAccount_analytic_lineService account_analytic_lineService;

    @Autowired
    @Lazy
    public Account_analytic_lineMapping account_analytic_lineMapping;

    @PreAuthorize("hasPermission(this.account_analytic_lineMapping.toDomain(#account_analytic_linedto),'iBizBusinessCentral-Account_analytic_line-Create')")
    @ApiOperation(value = "新建分析行", tags = {"分析行" },  notes = "新建分析行")
	@RequestMapping(method = RequestMethod.POST, value = "/account_analytic_lines")
    public ResponseEntity<Account_analytic_lineDTO> create(@Validated @RequestBody Account_analytic_lineDTO account_analytic_linedto) {
        Account_analytic_line domain = account_analytic_lineMapping.toDomain(account_analytic_linedto);
		account_analytic_lineService.create(domain);
        Account_analytic_lineDTO dto = account_analytic_lineMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.account_analytic_lineMapping.toDomain(#account_analytic_linedtos),'iBizBusinessCentral-Account_analytic_line-Create')")
    @ApiOperation(value = "批量新建分析行", tags = {"分析行" },  notes = "批量新建分析行")
	@RequestMapping(method = RequestMethod.POST, value = "/account_analytic_lines/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<Account_analytic_lineDTO> account_analytic_linedtos) {
        account_analytic_lineService.createBatch(account_analytic_lineMapping.toDomain(account_analytic_linedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "account_analytic_line" , versionfield = "writeDate")
    @PreAuthorize("hasPermission(this.account_analytic_lineService.get(#account_analytic_line_id),'iBizBusinessCentral-Account_analytic_line-Update')")
    @ApiOperation(value = "更新分析行", tags = {"分析行" },  notes = "更新分析行")
	@RequestMapping(method = RequestMethod.PUT, value = "/account_analytic_lines/{account_analytic_line_id}")
    public ResponseEntity<Account_analytic_lineDTO> update(@PathVariable("account_analytic_line_id") Long account_analytic_line_id, @RequestBody Account_analytic_lineDTO account_analytic_linedto) {
		Account_analytic_line domain  = account_analytic_lineMapping.toDomain(account_analytic_linedto);
        domain .setId(account_analytic_line_id);
		account_analytic_lineService.update(domain );
		Account_analytic_lineDTO dto = account_analytic_lineMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.account_analytic_lineService.getAccountAnalyticLineByEntities(this.account_analytic_lineMapping.toDomain(#account_analytic_linedtos)),'iBizBusinessCentral-Account_analytic_line-Update')")
    @ApiOperation(value = "批量更新分析行", tags = {"分析行" },  notes = "批量更新分析行")
	@RequestMapping(method = RequestMethod.PUT, value = "/account_analytic_lines/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<Account_analytic_lineDTO> account_analytic_linedtos) {
        account_analytic_lineService.updateBatch(account_analytic_lineMapping.toDomain(account_analytic_linedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission(this.account_analytic_lineService.get(#account_analytic_line_id),'iBizBusinessCentral-Account_analytic_line-Remove')")
    @ApiOperation(value = "删除分析行", tags = {"分析行" },  notes = "删除分析行")
	@RequestMapping(method = RequestMethod.DELETE, value = "/account_analytic_lines/{account_analytic_line_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("account_analytic_line_id") Long account_analytic_line_id) {
         return ResponseEntity.status(HttpStatus.OK).body(account_analytic_lineService.remove(account_analytic_line_id));
    }

    @PreAuthorize("hasPermission(this.account_analytic_lineService.getAccountAnalyticLineByIds(#ids),'iBizBusinessCentral-Account_analytic_line-Remove')")
    @ApiOperation(value = "批量删除分析行", tags = {"分析行" },  notes = "批量删除分析行")
	@RequestMapping(method = RequestMethod.DELETE, value = "/account_analytic_lines/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<Long> ids) {
        account_analytic_lineService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PostAuthorize("hasPermission(this.account_analytic_lineMapping.toDomain(returnObject.body),'iBizBusinessCentral-Account_analytic_line-Get')")
    @ApiOperation(value = "获取分析行", tags = {"分析行" },  notes = "获取分析行")
	@RequestMapping(method = RequestMethod.GET, value = "/account_analytic_lines/{account_analytic_line_id}")
    public ResponseEntity<Account_analytic_lineDTO> get(@PathVariable("account_analytic_line_id") Long account_analytic_line_id) {
        Account_analytic_line domain = account_analytic_lineService.get(account_analytic_line_id);
        Account_analytic_lineDTO dto = account_analytic_lineMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }


}

