package cn.ibizlab.businesscentral.core.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.businesscentral.core.dto.*;
import cn.ibizlab.businesscentral.core.mapping.*;
import cn.ibizlab.businesscentral.core.odoo_hr.domain.Hr_expense_refuse_wizard;
import cn.ibizlab.businesscentral.core.odoo_hr.service.IHr_expense_refuse_wizardService;
import cn.ibizlab.businesscentral.core.odoo_hr.filter.Hr_expense_refuse_wizardSearchContext;
import cn.ibizlab.businesscentral.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"费用拒绝原因向导" })
@RestController("Core-hr_expense_refuse_wizard")
@RequestMapping("")
public class Hr_expense_refuse_wizardResource {

    @Autowired
    public IHr_expense_refuse_wizardService hr_expense_refuse_wizardService;

    @Autowired
    @Lazy
    public Hr_expense_refuse_wizardMapping hr_expense_refuse_wizardMapping;

    @PreAuthorize("hasPermission(this.hr_expense_refuse_wizardMapping.toDomain(#hr_expense_refuse_wizarddto),'iBizBusinessCentral-Hr_expense_refuse_wizard-Create')")
    @ApiOperation(value = "新建费用拒绝原因向导", tags = {"费用拒绝原因向导" },  notes = "新建费用拒绝原因向导")
	@RequestMapping(method = RequestMethod.POST, value = "/hr_expense_refuse_wizards")
    public ResponseEntity<Hr_expense_refuse_wizardDTO> create(@Validated @RequestBody Hr_expense_refuse_wizardDTO hr_expense_refuse_wizarddto) {
        Hr_expense_refuse_wizard domain = hr_expense_refuse_wizardMapping.toDomain(hr_expense_refuse_wizarddto);
		hr_expense_refuse_wizardService.create(domain);
        Hr_expense_refuse_wizardDTO dto = hr_expense_refuse_wizardMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.hr_expense_refuse_wizardMapping.toDomain(#hr_expense_refuse_wizarddtos),'iBizBusinessCentral-Hr_expense_refuse_wizard-Create')")
    @ApiOperation(value = "批量新建费用拒绝原因向导", tags = {"费用拒绝原因向导" },  notes = "批量新建费用拒绝原因向导")
	@RequestMapping(method = RequestMethod.POST, value = "/hr_expense_refuse_wizards/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<Hr_expense_refuse_wizardDTO> hr_expense_refuse_wizarddtos) {
        hr_expense_refuse_wizardService.createBatch(hr_expense_refuse_wizardMapping.toDomain(hr_expense_refuse_wizarddtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "hr_expense_refuse_wizard" , versionfield = "writeDate")
    @PreAuthorize("hasPermission(this.hr_expense_refuse_wizardService.get(#hr_expense_refuse_wizard_id),'iBizBusinessCentral-Hr_expense_refuse_wizard-Update')")
    @ApiOperation(value = "更新费用拒绝原因向导", tags = {"费用拒绝原因向导" },  notes = "更新费用拒绝原因向导")
	@RequestMapping(method = RequestMethod.PUT, value = "/hr_expense_refuse_wizards/{hr_expense_refuse_wizard_id}")
    public ResponseEntity<Hr_expense_refuse_wizardDTO> update(@PathVariable("hr_expense_refuse_wizard_id") Long hr_expense_refuse_wizard_id, @RequestBody Hr_expense_refuse_wizardDTO hr_expense_refuse_wizarddto) {
		Hr_expense_refuse_wizard domain  = hr_expense_refuse_wizardMapping.toDomain(hr_expense_refuse_wizarddto);
        domain .setId(hr_expense_refuse_wizard_id);
		hr_expense_refuse_wizardService.update(domain );
		Hr_expense_refuse_wizardDTO dto = hr_expense_refuse_wizardMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.hr_expense_refuse_wizardService.getHrExpenseRefuseWizardByEntities(this.hr_expense_refuse_wizardMapping.toDomain(#hr_expense_refuse_wizarddtos)),'iBizBusinessCentral-Hr_expense_refuse_wizard-Update')")
    @ApiOperation(value = "批量更新费用拒绝原因向导", tags = {"费用拒绝原因向导" },  notes = "批量更新费用拒绝原因向导")
	@RequestMapping(method = RequestMethod.PUT, value = "/hr_expense_refuse_wizards/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<Hr_expense_refuse_wizardDTO> hr_expense_refuse_wizarddtos) {
        hr_expense_refuse_wizardService.updateBatch(hr_expense_refuse_wizardMapping.toDomain(hr_expense_refuse_wizarddtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission(this.hr_expense_refuse_wizardService.get(#hr_expense_refuse_wizard_id),'iBizBusinessCentral-Hr_expense_refuse_wizard-Remove')")
    @ApiOperation(value = "删除费用拒绝原因向导", tags = {"费用拒绝原因向导" },  notes = "删除费用拒绝原因向导")
	@RequestMapping(method = RequestMethod.DELETE, value = "/hr_expense_refuse_wizards/{hr_expense_refuse_wizard_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("hr_expense_refuse_wizard_id") Long hr_expense_refuse_wizard_id) {
         return ResponseEntity.status(HttpStatus.OK).body(hr_expense_refuse_wizardService.remove(hr_expense_refuse_wizard_id));
    }

    @PreAuthorize("hasPermission(this.hr_expense_refuse_wizardService.getHrExpenseRefuseWizardByIds(#ids),'iBizBusinessCentral-Hr_expense_refuse_wizard-Remove')")
    @ApiOperation(value = "批量删除费用拒绝原因向导", tags = {"费用拒绝原因向导" },  notes = "批量删除费用拒绝原因向导")
	@RequestMapping(method = RequestMethod.DELETE, value = "/hr_expense_refuse_wizards/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<Long> ids) {
        hr_expense_refuse_wizardService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PostAuthorize("hasPermission(this.hr_expense_refuse_wizardMapping.toDomain(returnObject.body),'iBizBusinessCentral-Hr_expense_refuse_wizard-Get')")
    @ApiOperation(value = "获取费用拒绝原因向导", tags = {"费用拒绝原因向导" },  notes = "获取费用拒绝原因向导")
	@RequestMapping(method = RequestMethod.GET, value = "/hr_expense_refuse_wizards/{hr_expense_refuse_wizard_id}")
    public ResponseEntity<Hr_expense_refuse_wizardDTO> get(@PathVariable("hr_expense_refuse_wizard_id") Long hr_expense_refuse_wizard_id) {
        Hr_expense_refuse_wizard domain = hr_expense_refuse_wizardService.get(hr_expense_refuse_wizard_id);
        Hr_expense_refuse_wizardDTO dto = hr_expense_refuse_wizardMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }


}

