package cn.ibizlab.businesscentral.core.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.businesscentral.core.dto.*;
import cn.ibizlab.businesscentral.core.mapping.*;
import cn.ibizlab.businesscentral.core.odoo_mail.domain.Mail_mass_mailing_list_contact_rel;
import cn.ibizlab.businesscentral.core.odoo_mail.service.IMail_mass_mailing_list_contact_relService;
import cn.ibizlab.businesscentral.core.odoo_mail.filter.Mail_mass_mailing_list_contact_relSearchContext;
import cn.ibizlab.businesscentral.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"群发邮件订阅信息" })
@RestController("Core-mail_mass_mailing_list_contact_rel")
@RequestMapping("")
public class Mail_mass_mailing_list_contact_relResource {

    @Autowired
    public IMail_mass_mailing_list_contact_relService mail_mass_mailing_list_contact_relService;

    @Autowired
    @Lazy
    public Mail_mass_mailing_list_contact_relMapping mail_mass_mailing_list_contact_relMapping;

    @PreAuthorize("hasPermission(this.mail_mass_mailing_list_contact_relMapping.toDomain(#mail_mass_mailing_list_contact_reldto),'iBizBusinessCentral-Mail_mass_mailing_list_contact_rel-Create')")
    @ApiOperation(value = "新建群发邮件订阅信息", tags = {"群发邮件订阅信息" },  notes = "新建群发邮件订阅信息")
	@RequestMapping(method = RequestMethod.POST, value = "/mail_mass_mailing_list_contact_rels")
    public ResponseEntity<Mail_mass_mailing_list_contact_relDTO> create(@Validated @RequestBody Mail_mass_mailing_list_contact_relDTO mail_mass_mailing_list_contact_reldto) {
        Mail_mass_mailing_list_contact_rel domain = mail_mass_mailing_list_contact_relMapping.toDomain(mail_mass_mailing_list_contact_reldto);
		mail_mass_mailing_list_contact_relService.create(domain);
        Mail_mass_mailing_list_contact_relDTO dto = mail_mass_mailing_list_contact_relMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.mail_mass_mailing_list_contact_relMapping.toDomain(#mail_mass_mailing_list_contact_reldtos),'iBizBusinessCentral-Mail_mass_mailing_list_contact_rel-Create')")
    @ApiOperation(value = "批量新建群发邮件订阅信息", tags = {"群发邮件订阅信息" },  notes = "批量新建群发邮件订阅信息")
	@RequestMapping(method = RequestMethod.POST, value = "/mail_mass_mailing_list_contact_rels/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<Mail_mass_mailing_list_contact_relDTO> mail_mass_mailing_list_contact_reldtos) {
        mail_mass_mailing_list_contact_relService.createBatch(mail_mass_mailing_list_contact_relMapping.toDomain(mail_mass_mailing_list_contact_reldtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "mail_mass_mailing_list_contact_rel" , versionfield = "writeDate")
    @PreAuthorize("hasPermission(this.mail_mass_mailing_list_contact_relService.get(#mail_mass_mailing_list_contact_rel_id),'iBizBusinessCentral-Mail_mass_mailing_list_contact_rel-Update')")
    @ApiOperation(value = "更新群发邮件订阅信息", tags = {"群发邮件订阅信息" },  notes = "更新群发邮件订阅信息")
	@RequestMapping(method = RequestMethod.PUT, value = "/mail_mass_mailing_list_contact_rels/{mail_mass_mailing_list_contact_rel_id}")
    public ResponseEntity<Mail_mass_mailing_list_contact_relDTO> update(@PathVariable("mail_mass_mailing_list_contact_rel_id") Long mail_mass_mailing_list_contact_rel_id, @RequestBody Mail_mass_mailing_list_contact_relDTO mail_mass_mailing_list_contact_reldto) {
		Mail_mass_mailing_list_contact_rel domain  = mail_mass_mailing_list_contact_relMapping.toDomain(mail_mass_mailing_list_contact_reldto);
        domain .setId(mail_mass_mailing_list_contact_rel_id);
		mail_mass_mailing_list_contact_relService.update(domain );
		Mail_mass_mailing_list_contact_relDTO dto = mail_mass_mailing_list_contact_relMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.mail_mass_mailing_list_contact_relService.getMailMassMailingListContactRelByEntities(this.mail_mass_mailing_list_contact_relMapping.toDomain(#mail_mass_mailing_list_contact_reldtos)),'iBizBusinessCentral-Mail_mass_mailing_list_contact_rel-Update')")
    @ApiOperation(value = "批量更新群发邮件订阅信息", tags = {"群发邮件订阅信息" },  notes = "批量更新群发邮件订阅信息")
	@RequestMapping(method = RequestMethod.PUT, value = "/mail_mass_mailing_list_contact_rels/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<Mail_mass_mailing_list_contact_relDTO> mail_mass_mailing_list_contact_reldtos) {
        mail_mass_mailing_list_contact_relService.updateBatch(mail_mass_mailing_list_contact_relMapping.toDomain(mail_mass_mailing_list_contact_reldtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission(this.mail_mass_mailing_list_contact_relService.get(#mail_mass_mailing_list_contact_rel_id),'iBizBusinessCentral-Mail_mass_mailing_list_contact_rel-Remove')")
    @ApiOperation(value = "删除群发邮件订阅信息", tags = {"群发邮件订阅信息" },  notes = "删除群发邮件订阅信息")
	@RequestMapping(method = RequestMethod.DELETE, value = "/mail_mass_mailing_list_contact_rels/{mail_mass_mailing_list_contact_rel_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("mail_mass_mailing_list_contact_rel_id") Long mail_mass_mailing_list_contact_rel_id) {
         return ResponseEntity.status(HttpStatus.OK).body(mail_mass_mailing_list_contact_relService.remove(mail_mass_mailing_list_contact_rel_id));
    }

    @PreAuthorize("hasPermission(this.mail_mass_mailing_list_contact_relService.getMailMassMailingListContactRelByIds(#ids),'iBizBusinessCentral-Mail_mass_mailing_list_contact_rel-Remove')")
    @ApiOperation(value = "批量删除群发邮件订阅信息", tags = {"群发邮件订阅信息" },  notes = "批量删除群发邮件订阅信息")
	@RequestMapping(method = RequestMethod.DELETE, value = "/mail_mass_mailing_list_contact_rels/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<Long> ids) {
        mail_mass_mailing_list_contact_relService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PostAuthorize("hasPermission(this.mail_mass_mailing_list_contact_relMapping.toDomain(returnObject.body),'iBizBusinessCentral-Mail_mass_mailing_list_contact_rel-Get')")
    @ApiOperation(value = "获取群发邮件订阅信息", tags = {"群发邮件订阅信息" },  notes = "获取群发邮件订阅信息")
	@RequestMapping(method = RequestMethod.GET, value = "/mail_mass_mailing_list_contact_rels/{mail_mass_mailing_list_contact_rel_id}")
    public ResponseEntity<Mail_mass_mailing_list_contact_relDTO> get(@PathVariable("mail_mass_mailing_list_contact_rel_id") Long mail_mass_mailing_list_contact_rel_id) {
        Mail_mass_mailing_list_contact_rel domain = mail_mass_mailing_list_contact_relService.get(mail_mass_mailing_list_contact_rel_id);
        Mail_mass_mailing_list_contact_relDTO dto = mail_mass_mailing_list_contact_relMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }


}

