package cn.ibizlab.businesscentral.core.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.businesscentral.core.dto.*;
import cn.ibizlab.businesscentral.core.mapping.*;
import cn.ibizlab.businesscentral.core.odoo_mro.domain.Mro_order_parts_line;
import cn.ibizlab.businesscentral.core.odoo_mro.service.IMro_order_parts_lineService;
import cn.ibizlab.businesscentral.core.odoo_mro.filter.Mro_order_parts_lineSearchContext;
import cn.ibizlab.businesscentral.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"Maintenance Planned Parts" })
@RestController("Core-mro_order_parts_line")
@RequestMapping("")
public class Mro_order_parts_lineResource {

    @Autowired
    public IMro_order_parts_lineService mro_order_parts_lineService;

    @Autowired
    @Lazy
    public Mro_order_parts_lineMapping mro_order_parts_lineMapping;

    @PreAuthorize("hasPermission(this.mro_order_parts_lineMapping.toDomain(#mro_order_parts_linedto),'iBizBusinessCentral-Mro_order_parts_line-Create')")
    @ApiOperation(value = "新建Maintenance Planned Parts", tags = {"Maintenance Planned Parts" },  notes = "新建Maintenance Planned Parts")
	@RequestMapping(method = RequestMethod.POST, value = "/mro_order_parts_lines")
    public ResponseEntity<Mro_order_parts_lineDTO> create(@Validated @RequestBody Mro_order_parts_lineDTO mro_order_parts_linedto) {
        Mro_order_parts_line domain = mro_order_parts_lineMapping.toDomain(mro_order_parts_linedto);
		mro_order_parts_lineService.create(domain);
        Mro_order_parts_lineDTO dto = mro_order_parts_lineMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.mro_order_parts_lineMapping.toDomain(#mro_order_parts_linedtos),'iBizBusinessCentral-Mro_order_parts_line-Create')")
    @ApiOperation(value = "批量新建Maintenance Planned Parts", tags = {"Maintenance Planned Parts" },  notes = "批量新建Maintenance Planned Parts")
	@RequestMapping(method = RequestMethod.POST, value = "/mro_order_parts_lines/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<Mro_order_parts_lineDTO> mro_order_parts_linedtos) {
        mro_order_parts_lineService.createBatch(mro_order_parts_lineMapping.toDomain(mro_order_parts_linedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "mro_order_parts_line" , versionfield = "writeDate")
    @PreAuthorize("hasPermission(this.mro_order_parts_lineService.get(#mro_order_parts_line_id),'iBizBusinessCentral-Mro_order_parts_line-Update')")
    @ApiOperation(value = "更新Maintenance Planned Parts", tags = {"Maintenance Planned Parts" },  notes = "更新Maintenance Planned Parts")
	@RequestMapping(method = RequestMethod.PUT, value = "/mro_order_parts_lines/{mro_order_parts_line_id}")
    public ResponseEntity<Mro_order_parts_lineDTO> update(@PathVariable("mro_order_parts_line_id") Long mro_order_parts_line_id, @RequestBody Mro_order_parts_lineDTO mro_order_parts_linedto) {
		Mro_order_parts_line domain  = mro_order_parts_lineMapping.toDomain(mro_order_parts_linedto);
        domain .setId(mro_order_parts_line_id);
		mro_order_parts_lineService.update(domain );
		Mro_order_parts_lineDTO dto = mro_order_parts_lineMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.mro_order_parts_lineService.getMroOrderPartsLineByEntities(this.mro_order_parts_lineMapping.toDomain(#mro_order_parts_linedtos)),'iBizBusinessCentral-Mro_order_parts_line-Update')")
    @ApiOperation(value = "批量更新Maintenance Planned Parts", tags = {"Maintenance Planned Parts" },  notes = "批量更新Maintenance Planned Parts")
	@RequestMapping(method = RequestMethod.PUT, value = "/mro_order_parts_lines/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<Mro_order_parts_lineDTO> mro_order_parts_linedtos) {
        mro_order_parts_lineService.updateBatch(mro_order_parts_lineMapping.toDomain(mro_order_parts_linedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission(this.mro_order_parts_lineService.get(#mro_order_parts_line_id),'iBizBusinessCentral-Mro_order_parts_line-Remove')")
    @ApiOperation(value = "删除Maintenance Planned Parts", tags = {"Maintenance Planned Parts" },  notes = "删除Maintenance Planned Parts")
	@RequestMapping(method = RequestMethod.DELETE, value = "/mro_order_parts_lines/{mro_order_parts_line_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("mro_order_parts_line_id") Long mro_order_parts_line_id) {
         return ResponseEntity.status(HttpStatus.OK).body(mro_order_parts_lineService.remove(mro_order_parts_line_id));
    }

    @PreAuthorize("hasPermission(this.mro_order_parts_lineService.getMroOrderPartsLineByIds(#ids),'iBizBusinessCentral-Mro_order_parts_line-Remove')")
    @ApiOperation(value = "批量删除Maintenance Planned Parts", tags = {"Maintenance Planned Parts" },  notes = "批量删除Maintenance Planned Parts")
	@RequestMapping(method = RequestMethod.DELETE, value = "/mro_order_parts_lines/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<Long> ids) {
        mro_order_parts_lineService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PostAuthorize("hasPermission(this.mro_order_parts_lineMapping.toDomain(returnObject.body),'iBizBusinessCentral-Mro_order_parts_line-Get')")
    @ApiOperation(value = "获取Maintenance Planned Parts", tags = {"Maintenance Planned Parts" },  notes = "获取Maintenance Planned Parts")
	@RequestMapping(method = RequestMethod.GET, value = "/mro_order_parts_lines/{mro_order_parts_line_id}")
    public ResponseEntity<Mro_order_parts_lineDTO> get(@PathVariable("mro_order_parts_line_id") Long mro_order_parts_line_id) {
        Mro_order_parts_line domain = mro_order_parts_lineService.get(mro_order_parts_line_id);
        Mro_order_parts_lineDTO dto = mro_order_parts_lineMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }


}

