package cn.ibizlab.businesscentral.core.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.businesscentral.core.dto.*;
import cn.ibizlab.businesscentral.core.mapping.*;
import cn.ibizlab.businesscentral.core.odoo_mrp.domain.Mrp_bom;
import cn.ibizlab.businesscentral.core.odoo_mrp.service.IMrp_bomService;
import cn.ibizlab.businesscentral.core.odoo_mrp.filter.Mrp_bomSearchContext;
import cn.ibizlab.businesscentral.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"物料清单" })
@RestController("Core-mrp_bom")
@RequestMapping("")
public class Mrp_bomResource {

    @Autowired
    public IMrp_bomService mrp_bomService;

    @Autowired
    @Lazy
    public Mrp_bomMapping mrp_bomMapping;

    @PreAuthorize("hasPermission(this.mrp_bomMapping.toDomain(#mrp_bomdto),'iBizBusinessCentral-Mrp_bom-Create')")
    @ApiOperation(value = "新建物料清单", tags = {"物料清单" },  notes = "新建物料清单")
	@RequestMapping(method = RequestMethod.POST, value = "/mrp_boms")
    public ResponseEntity<Mrp_bomDTO> create(@Validated @RequestBody Mrp_bomDTO mrp_bomdto) {
        Mrp_bom domain = mrp_bomMapping.toDomain(mrp_bomdto);
		mrp_bomService.create(domain);
        Mrp_bomDTO dto = mrp_bomMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.mrp_bomMapping.toDomain(#mrp_bomdtos),'iBizBusinessCentral-Mrp_bom-Create')")
    @ApiOperation(value = "批量新建物料清单", tags = {"物料清单" },  notes = "批量新建物料清单")
	@RequestMapping(method = RequestMethod.POST, value = "/mrp_boms/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<Mrp_bomDTO> mrp_bomdtos) {
        mrp_bomService.createBatch(mrp_bomMapping.toDomain(mrp_bomdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "mrp_bom" , versionfield = "writeDate")
    @PreAuthorize("hasPermission(this.mrp_bomService.get(#mrp_bom_id),'iBizBusinessCentral-Mrp_bom-Update')")
    @ApiOperation(value = "更新物料清单", tags = {"物料清单" },  notes = "更新物料清单")
	@RequestMapping(method = RequestMethod.PUT, value = "/mrp_boms/{mrp_bom_id}")
    public ResponseEntity<Mrp_bomDTO> update(@PathVariable("mrp_bom_id") Long mrp_bom_id, @RequestBody Mrp_bomDTO mrp_bomdto) {
		Mrp_bom domain  = mrp_bomMapping.toDomain(mrp_bomdto);
        domain .setId(mrp_bom_id);
		mrp_bomService.update(domain );
		Mrp_bomDTO dto = mrp_bomMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.mrp_bomService.getMrpBomByEntities(this.mrp_bomMapping.toDomain(#mrp_bomdtos)),'iBizBusinessCentral-Mrp_bom-Update')")
    @ApiOperation(value = "批量更新物料清单", tags = {"物料清单" },  notes = "批量更新物料清单")
	@RequestMapping(method = RequestMethod.PUT, value = "/mrp_boms/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<Mrp_bomDTO> mrp_bomdtos) {
        mrp_bomService.updateBatch(mrp_bomMapping.toDomain(mrp_bomdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission(this.mrp_bomService.get(#mrp_bom_id),'iBizBusinessCentral-Mrp_bom-Remove')")
    @ApiOperation(value = "删除物料清单", tags = {"物料清单" },  notes = "删除物料清单")
	@RequestMapping(method = RequestMethod.DELETE, value = "/mrp_boms/{mrp_bom_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("mrp_bom_id") Long mrp_bom_id) {
         return ResponseEntity.status(HttpStatus.OK).body(mrp_bomService.remove(mrp_bom_id));
    }

    @PreAuthorize("hasPermission(this.mrp_bomService.getMrpBomByIds(#ids),'iBizBusinessCentral-Mrp_bom-Remove')")
    @ApiOperation(value = "批量删除物料清单", tags = {"物料清单" },  notes = "批量删除物料清单")
	@RequestMapping(method = RequestMethod.DELETE, value = "/mrp_boms/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<Long> ids) {
        mrp_bomService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PostAuthorize("hasPermission(this.mrp_bomMapping.toDomain(returnObject.body),'iBizBusinessCentral-Mrp_bom-Get')")
    @ApiOperation(value = "获取物料清单", tags = {"物料清单" },  notes = "获取物料清单")
	@RequestMapping(method = RequestMethod.GET, value = "/mrp_boms/{mrp_bom_id}")
    public ResponseEntity<Mrp_bomDTO> get(@PathVariable("mrp_bom_id") Long mrp_bom_id) {
        Mrp_bom domain = mrp_bomService.get(mrp_bom_id);
        Mrp_bomDTO dto = mrp_bomMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }


}

