package cn.ibizlab.businesscentral.core.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.businesscentral.core.dto.*;
import cn.ibizlab.businesscentral.core.mapping.*;
import cn.ibizlab.businesscentral.core.odoo_product.domain.Product_template_attribute_line;
import cn.ibizlab.businesscentral.core.odoo_product.service.IProduct_template_attribute_lineService;
import cn.ibizlab.businesscentral.core.odoo_product.filter.Product_template_attribute_lineSearchContext;
import cn.ibizlab.businesscentral.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"产品模板属性明细行" })
@RestController("Core-product_template_attribute_line")
@RequestMapping("")
public class Product_template_attribute_lineResource {

    @Autowired
    public IProduct_template_attribute_lineService product_template_attribute_lineService;

    @Autowired
    @Lazy
    public Product_template_attribute_lineMapping product_template_attribute_lineMapping;

    @PreAuthorize("hasPermission(this.product_template_attribute_lineMapping.toDomain(#product_template_attribute_linedto),'iBizBusinessCentral-Product_template_attribute_line-Create')")
    @ApiOperation(value = "新建产品模板属性明细行", tags = {"产品模板属性明细行" },  notes = "新建产品模板属性明细行")
	@RequestMapping(method = RequestMethod.POST, value = "/product_template_attribute_lines")
    public ResponseEntity<Product_template_attribute_lineDTO> create(@Validated @RequestBody Product_template_attribute_lineDTO product_template_attribute_linedto) {
        Product_template_attribute_line domain = product_template_attribute_lineMapping.toDomain(product_template_attribute_linedto);
		product_template_attribute_lineService.create(domain);
        Product_template_attribute_lineDTO dto = product_template_attribute_lineMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.product_template_attribute_lineMapping.toDomain(#product_template_attribute_linedtos),'iBizBusinessCentral-Product_template_attribute_line-Create')")
    @ApiOperation(value = "批量新建产品模板属性明细行", tags = {"产品模板属性明细行" },  notes = "批量新建产品模板属性明细行")
	@RequestMapping(method = RequestMethod.POST, value = "/product_template_attribute_lines/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<Product_template_attribute_lineDTO> product_template_attribute_linedtos) {
        product_template_attribute_lineService.createBatch(product_template_attribute_lineMapping.toDomain(product_template_attribute_linedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "product_template_attribute_line" , versionfield = "writeDate")
    @PreAuthorize("hasPermission(this.product_template_attribute_lineService.get(#product_template_attribute_line_id),'iBizBusinessCentral-Product_template_attribute_line-Update')")
    @ApiOperation(value = "更新产品模板属性明细行", tags = {"产品模板属性明细行" },  notes = "更新产品模板属性明细行")
	@RequestMapping(method = RequestMethod.PUT, value = "/product_template_attribute_lines/{product_template_attribute_line_id}")
    public ResponseEntity<Product_template_attribute_lineDTO> update(@PathVariable("product_template_attribute_line_id") Long product_template_attribute_line_id, @RequestBody Product_template_attribute_lineDTO product_template_attribute_linedto) {
		Product_template_attribute_line domain  = product_template_attribute_lineMapping.toDomain(product_template_attribute_linedto);
        domain .setId(product_template_attribute_line_id);
		product_template_attribute_lineService.update(domain );
		Product_template_attribute_lineDTO dto = product_template_attribute_lineMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.product_template_attribute_lineService.getProductTemplateAttributeLineByEntities(this.product_template_attribute_lineMapping.toDomain(#product_template_attribute_linedtos)),'iBizBusinessCentral-Product_template_attribute_line-Update')")
    @ApiOperation(value = "批量更新产品模板属性明细行", tags = {"产品模板属性明细行" },  notes = "批量更新产品模板属性明细行")
	@RequestMapping(method = RequestMethod.PUT, value = "/product_template_attribute_lines/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<Product_template_attribute_lineDTO> product_template_attribute_linedtos) {
        product_template_attribute_lineService.updateBatch(product_template_attribute_lineMapping.toDomain(product_template_attribute_linedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission(this.product_template_attribute_lineService.get(#product_template_attribute_line_id),'iBizBusinessCentral-Product_template_attribute_line-Remove')")
    @ApiOperation(value = "删除产品模板属性明细行", tags = {"产品模板属性明细行" },  notes = "删除产品模板属性明细行")
	@RequestMapping(method = RequestMethod.DELETE, value = "/product_template_attribute_lines/{product_template_attribute_line_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("product_template_attribute_line_id") Long product_template_attribute_line_id) {
         return ResponseEntity.status(HttpStatus.OK).body(product_template_attribute_lineService.remove(product_template_attribute_line_id));
    }

    @PreAuthorize("hasPermission(this.product_template_attribute_lineService.getProductTemplateAttributeLineByIds(#ids),'iBizBusinessCentral-Product_template_attribute_line-Remove')")
    @ApiOperation(value = "批量删除产品模板属性明细行", tags = {"产品模板属性明细行" },  notes = "批量删除产品模板属性明细行")
	@RequestMapping(method = RequestMethod.DELETE, value = "/product_template_attribute_lines/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<Long> ids) {
        product_template_attribute_lineService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PostAuthorize("hasPermission(this.product_template_attribute_lineMapping.toDomain(returnObject.body),'iBizBusinessCentral-Product_template_attribute_line-Get')")
    @ApiOperation(value = "获取产品模板属性明细行", tags = {"产品模板属性明细行" },  notes = "获取产品模板属性明细行")
	@RequestMapping(method = RequestMethod.GET, value = "/product_template_attribute_lines/{product_template_attribute_line_id}")
    public ResponseEntity<Product_template_attribute_lineDTO> get(@PathVariable("product_template_attribute_line_id") Long product_template_attribute_line_id) {
        Product_template_attribute_line domain = product_template_attribute_lineService.get(product_template_attribute_line_id);
        Product_template_attribute_lineDTO dto = product_template_attribute_lineMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }


}

