package cn.ibizlab.businesscentral.core.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.businesscentral.core.dto.*;
import cn.ibizlab.businesscentral.core.mapping.*;
import cn.ibizlab.businesscentral.core.odoo_purchase.domain.Purchase_order;
import cn.ibizlab.businesscentral.core.odoo_purchase.service.IPurchase_orderService;
import cn.ibizlab.businesscentral.core.odoo_purchase.filter.Purchase_orderSearchContext;
import cn.ibizlab.businesscentral.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"采购订单" })
@RestController("Core-purchase_order")
@RequestMapping("")
public class Purchase_orderResource {

    @Autowired
    public IPurchase_orderService purchase_orderService;

    @Autowired
    @Lazy
    public Purchase_orderMapping purchase_orderMapping;

    @PreAuthorize("hasPermission(this.purchase_orderMapping.toDomain(#purchase_orderdto),'iBizBusinessCentral-Purchase_order-Create')")
    @ApiOperation(value = "新建采购订单", tags = {"采购订单" },  notes = "新建采购订单")
	@RequestMapping(method = RequestMethod.POST, value = "/purchase_orders")
    public ResponseEntity<Purchase_orderDTO> create(@Validated @RequestBody Purchase_orderDTO purchase_orderdto) {
        Purchase_order domain = purchase_orderMapping.toDomain(purchase_orderdto);
		purchase_orderService.create(domain);
        Purchase_orderDTO dto = purchase_orderMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.purchase_orderMapping.toDomain(#purchase_orderdtos),'iBizBusinessCentral-Purchase_order-Create')")
    @ApiOperation(value = "批量新建采购订单", tags = {"采购订单" },  notes = "批量新建采购订单")
	@RequestMapping(method = RequestMethod.POST, value = "/purchase_orders/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<Purchase_orderDTO> purchase_orderdtos) {
        purchase_orderService.createBatch(purchase_orderMapping.toDomain(purchase_orderdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "purchase_order" , versionfield = "writeDate")
    @PreAuthorize("hasPermission(this.purchase_orderService.get(#purchase_order_id),'iBizBusinessCentral-Purchase_order-Update')")
    @ApiOperation(value = "更新采购订单", tags = {"采购订单" },  notes = "更新采购订单")
	@RequestMapping(method = RequestMethod.PUT, value = "/purchase_orders/{purchase_order_id}")
    public ResponseEntity<Purchase_orderDTO> update(@PathVariable("purchase_order_id") Long purchase_order_id, @RequestBody Purchase_orderDTO purchase_orderdto) {
		Purchase_order domain  = purchase_orderMapping.toDomain(purchase_orderdto);
        domain .setId(purchase_order_id);
		purchase_orderService.update(domain );
		Purchase_orderDTO dto = purchase_orderMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.purchase_orderService.getPurchaseOrderByEntities(this.purchase_orderMapping.toDomain(#purchase_orderdtos)),'iBizBusinessCentral-Purchase_order-Update')")
    @ApiOperation(value = "批量更新采购订单", tags = {"采购订单" },  notes = "批量更新采购订单")
	@RequestMapping(method = RequestMethod.PUT, value = "/purchase_orders/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<Purchase_orderDTO> purchase_orderdtos) {
        purchase_orderService.updateBatch(purchase_orderMapping.toDomain(purchase_orderdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission(this.purchase_orderService.get(#purchase_order_id),'iBizBusinessCentral-Purchase_order-Remove')")
    @ApiOperation(value = "删除采购订单", tags = {"采购订单" },  notes = "删除采购订单")
	@RequestMapping(method = RequestMethod.DELETE, value = "/purchase_orders/{purchase_order_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("purchase_order_id") Long purchase_order_id) {
         return ResponseEntity.status(HttpStatus.OK).body(purchase_orderService.remove(purchase_order_id));
    }

    @PreAuthorize("hasPermission(this.purchase_orderService.getPurchaseOrderByIds(#ids),'iBizBusinessCentral-Purchase_order-Remove')")
    @ApiOperation(value = "批量删除采购订单", tags = {"采购订单" },  notes = "批量删除采购订单")
	@RequestMapping(method = RequestMethod.DELETE, value = "/purchase_orders/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<Long> ids) {
        purchase_orderService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PostAuthorize("hasPermission(this.purchase_orderMapping.toDomain(returnObject.body),'iBizBusinessCentral-Purchase_order-Get')")
    @ApiOperation(value = "获取采购订单", tags = {"采购订单" },  notes = "获取采购订单")
	@RequestMapping(method = RequestMethod.GET, value = "/purchase_orders/{purchase_order_id}")
    public ResponseEntity<Purchase_orderDTO> get(@PathVariable("purchase_order_id") Long purchase_order_id) {
        Purchase_order domain = purchase_orderService.get(purchase_order_id);
        Purchase_orderDTO dto = purchase_orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }


}

