package cn.ibizlab.businesscentral.core.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.businesscentral.core.dto.*;
import cn.ibizlab.businesscentral.core.mapping.*;
import cn.ibizlab.businesscentral.core.odoo_purchase.domain.Purchase_order_line;
import cn.ibizlab.businesscentral.core.odoo_purchase.service.IPurchase_order_lineService;
import cn.ibizlab.businesscentral.core.odoo_purchase.filter.Purchase_order_lineSearchContext;
import cn.ibizlab.businesscentral.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"采购订单行" })
@RestController("Core-purchase_order_line")
@RequestMapping("")
public class Purchase_order_lineResource {

    @Autowired
    public IPurchase_order_lineService purchase_order_lineService;

    @Autowired
    @Lazy
    public Purchase_order_lineMapping purchase_order_lineMapping;

    @PreAuthorize("hasPermission(this.purchase_order_lineMapping.toDomain(#purchase_order_linedto),'iBizBusinessCentral-Purchase_order_line-Create')")
    @ApiOperation(value = "新建采购订单行", tags = {"采购订单行" },  notes = "新建采购订单行")
	@RequestMapping(method = RequestMethod.POST, value = "/purchase_order_lines")
    public ResponseEntity<Purchase_order_lineDTO> create(@Validated @RequestBody Purchase_order_lineDTO purchase_order_linedto) {
        Purchase_order_line domain = purchase_order_lineMapping.toDomain(purchase_order_linedto);
		purchase_order_lineService.create(domain);
        Purchase_order_lineDTO dto = purchase_order_lineMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.purchase_order_lineMapping.toDomain(#purchase_order_linedtos),'iBizBusinessCentral-Purchase_order_line-Create')")
    @ApiOperation(value = "批量新建采购订单行", tags = {"采购订单行" },  notes = "批量新建采购订单行")
	@RequestMapping(method = RequestMethod.POST, value = "/purchase_order_lines/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<Purchase_order_lineDTO> purchase_order_linedtos) {
        purchase_order_lineService.createBatch(purchase_order_lineMapping.toDomain(purchase_order_linedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "purchase_order_line" , versionfield = "writeDate")
    @PreAuthorize("hasPermission(this.purchase_order_lineService.get(#purchase_order_line_id),'iBizBusinessCentral-Purchase_order_line-Update')")
    @ApiOperation(value = "更新采购订单行", tags = {"采购订单行" },  notes = "更新采购订单行")
	@RequestMapping(method = RequestMethod.PUT, value = "/purchase_order_lines/{purchase_order_line_id}")
    public ResponseEntity<Purchase_order_lineDTO> update(@PathVariable("purchase_order_line_id") Long purchase_order_line_id, @RequestBody Purchase_order_lineDTO purchase_order_linedto) {
		Purchase_order_line domain  = purchase_order_lineMapping.toDomain(purchase_order_linedto);
        domain .setId(purchase_order_line_id);
		purchase_order_lineService.update(domain );
		Purchase_order_lineDTO dto = purchase_order_lineMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.purchase_order_lineService.getPurchaseOrderLineByEntities(this.purchase_order_lineMapping.toDomain(#purchase_order_linedtos)),'iBizBusinessCentral-Purchase_order_line-Update')")
    @ApiOperation(value = "批量更新采购订单行", tags = {"采购订单行" },  notes = "批量更新采购订单行")
	@RequestMapping(method = RequestMethod.PUT, value = "/purchase_order_lines/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<Purchase_order_lineDTO> purchase_order_linedtos) {
        purchase_order_lineService.updateBatch(purchase_order_lineMapping.toDomain(purchase_order_linedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission(this.purchase_order_lineService.get(#purchase_order_line_id),'iBizBusinessCentral-Purchase_order_line-Remove')")
    @ApiOperation(value = "删除采购订单行", tags = {"采购订单行" },  notes = "删除采购订单行")
	@RequestMapping(method = RequestMethod.DELETE, value = "/purchase_order_lines/{purchase_order_line_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("purchase_order_line_id") Long purchase_order_line_id) {
         return ResponseEntity.status(HttpStatus.OK).body(purchase_order_lineService.remove(purchase_order_line_id));
    }

    @PreAuthorize("hasPermission(this.purchase_order_lineService.getPurchaseOrderLineByIds(#ids),'iBizBusinessCentral-Purchase_order_line-Remove')")
    @ApiOperation(value = "批量删除采购订单行", tags = {"采购订单行" },  notes = "批量删除采购订单行")
	@RequestMapping(method = RequestMethod.DELETE, value = "/purchase_order_lines/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<Long> ids) {
        purchase_order_lineService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PostAuthorize("hasPermission(this.purchase_order_lineMapping.toDomain(returnObject.body),'iBizBusinessCentral-Purchase_order_line-Get')")
    @ApiOperation(value = "获取采购订单行", tags = {"采购订单行" },  notes = "获取采购订单行")
	@RequestMapping(method = RequestMethod.GET, value = "/purchase_order_lines/{purchase_order_line_id}")
    public ResponseEntity<Purchase_order_lineDTO> get(@PathVariable("purchase_order_line_id") Long purchase_order_line_id) {
        Purchase_order_line domain = purchase_order_lineService.get(purchase_order_line_id);
        Purchase_order_lineDTO dto = purchase_order_lineMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }


}

